@@ -1,11 +1,6 @@
-use crate::BytePos;
-use crate::Span;
-use crate::SyntaxContext;
+use crate::{BytePos, Span, SyntaxContext};
 use num_bigint::BigInt;
-use std::cell::RefCell;
-use std::cmp::PartialEq;
-use std::rc::Rc;
-use std::sync::Arc;
+use std::{cell::RefCell, cmp::PartialEq, rc::Rc, sync::Arc};
 use string_cache::Atom;
 
 /// Derive with `#[derive(EqIgnoreSpan)]`.
